@@ -6,7 +6,8 @@ class Configuration(object):
 
 	environments = {
 		'development': 'http://merchant-api:5000/api',
-		'production': 'https://sweetspot.so'
+		'production': 'https://sweetspot.so',
+		'test': 'http://localhost:5000/api'
 	}
 
 	def __init__(self, csrf_access_token=None, 
